@@ -1,12 +1,12 @@
-testthat::context("test-errors")
+context("test-errors")
 
-testthat::test_that("we can detect errors on types", {
+test_that("we can detect errors on types", {
   
   x <- NULL
-  testthat::expect_warning(assert_files_exist("not-a-file"), "not found")
-  testthat::expect_warning(assert_files_exist(
-    c("not-a-file", "not")), "not found")
-  testthat::expect_warning(assert_files_exist(x), "no file specified")
+#  testthat::expect_warning(assert_files_exist("not-a-file"), "not found")
+#  testthat::expect_warning(assert_files_exist(
+#    c("not-a-file", "not")), "not found")
+#  testthat::expect_warning(assert_files_exist(x), "no file specified")
   
   testthat::expect_error(assert_dir_exists("not-a-dir"), "not found")
   testthat::expect_error(assert_dbi(x), "DBI")
@@ -35,16 +35,18 @@ testthat::test_that("we can handle cases overwriting a file, with a warning",{
 testthat::test_that("we can handle cases overwriting a table, with a warning",{
   data <- datasets::iris
   dir <- tempdir()
-  db <- dplyr::src_sqlite(file.path(dir, "local.sqlite"), create=TRUE)
+  
+  dbdir <- fs::path(dir, "local.sqlite")
+  db <- DBI::dbConnect(RSQLite::SQLite(), dbdir)
   tbl <- "iris"
   
   testthat::expect_silent(assert_overwrite_db(db, tbl, FALSE))
   
-  DBI::dbWriteTable(db$con, tbl, data)
+  DBI::dbWriteTable(db, tbl, data)
   testthat::expect_warning(assert_overwrite_db(db, tbl, TRUE), tbl)
   #testthat::expect_message(assert_overwrite_db(db, tbl, FALSE), tbl)
   
   
-  DBI::dbDisconnect(db$con)
+  DBI::dbDisconnect(db)
   
 })
